/*
 * Copyright (C) 2017 Twitter, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#import <Foundation/Foundation.h>
#import <TwitterShareExtensionUI/TSENetworking.h>

@class TWTRTweet;

@protocol TWTRComposerNetworkingDelegate <NSObject>

@optional
- (void)didFinishSendingTweet:(TWTRTweet *)tweet;

- (void)didAbortSendingTweetWithError:(NSError *)error;

@end

/**
 *  Internal class to handle the shared composer networking
 *  tasks of sending a Tweet and loading users.
 */
@interface TWTRComposerNetworking : NSObject <TSENetworking>

@property (nonatomic, weak) id<TWTRComposerNetworkingDelegate> delegate;

/**
 *  Save video data for an in-progress composer session.
 *
 *  If a message comes back from the shared composer to send a Tweet, and this
 *  video data has been saved for upload, then the next Tweet will contain this
 *  video.
 */
- (void)prepareVideoData:(NSData *)videoData;

/**
 *  When the composer UI has been dismissed, or a Tweet is successfully sent,
 *  remove the pending video data.
 */
- (void)cancelPendingVideoUpload;

@end
